@echo on
set "CONDA_BUILD=1"
set "PYTHONNOUSERSITE=1"
set "CONDA_DEFAULT_ENV=D:\bld\metamorpheus_1621080809326\_h_env"
set "ARCH=64"
set "PREFIX=D:\bld\metamorpheus_1621080809326\_h_env"
set "BUILD_PREFIX=D:\bld\metamorpheus_1621080809326\_build_env"
set "SYS_PREFIX=C:\Miniconda"
set "SYS_PYTHON=C:\Miniconda\python.exe"
set "SUBDIR=win-64"
set "build_platform=win-64"
set "SRC_DIR=D:\bld\metamorpheus_1621080809326\work"
set "ROOT=C:\Miniconda"
set "CONDA_PY=36"
set "PY3K=1"
set "PY_VER=3.6"
set "STDLIB_DIR=D:\bld\metamorpheus_1621080809326\_h_env\Lib"
set "SP_DIR=D:\bld\metamorpheus_1621080809326\_h_env\Lib\site-packages"
set "NPY_VER=1.16"
set "CONDA_NPY=1.16"
set "NPY_DISTUTILS_APPEND_FLAGS=1"
set "PERL_VER=5.26"
set "CONDA_PERL=5.26.2"
set "LUA_VER=5"
set "CONDA_LUA=5"
set "R_VER=3.4"
set "CONDA_R=3.4"
set "PKG_NAME=metamorpheus"
set "PKG_VERSION=0.0.317"
set "PKG_BUILDNUM=2"
set "PKG_BUILD_STRING=placeholder"
set "PKG_HASH=1234567"
set "RECIPE_DIR=D:\a\1\s\recipe"
set "CPU_COUNT=2"
set "SHLIB_EXT=.dll"
set "PATH=D:\bld\metamorpheus_1621080809326\_build_env;D:\bld\metamorpheus_1621080809326\_build_env\Library\mingw-w64\bin;D:\bld\metamorpheus_1621080809326\_build_env\Library\usr\bin;;D:\bld\metamorpheus_1621080809326\_build_env\Library\bin;D:\bld\metamorpheus_1621080809326\_build_env\Scripts;D:\bld\metamorpheus_1621080809326\_build_env\Scripts;D:\bld\metamorpheus_1621080809326\_h_env;D:\bld\metamorpheus_1621080809326\_h_env\Library\mingw-w64\bin;D:\bld\metamorpheus_1621080809326\_h_env\Library\usr\bin;;D:\bld\metamorpheus_1621080809326\_h_env\Library\bin;D:\bld\metamorpheus_1621080809326\_h_env\Scripts;D:\bld\metamorpheus_1621080809326\_h_env\Scripts;C:\Miniconda;C:\Miniconda\Library\mingw-w64\bin;C:\Miniconda\Library\usr\bin;C:\Miniconda\Library\bin;C:\Miniconda\Scripts;C:\Miniconda\bin;C:\Miniconda\condabin;C:\Miniconda\Scripts;C:\Miniconda;C:\agents\2.186.1\externals\git\cmd;C:\Users\VssAdministrator\.dotnet\tools;C:\Program Files\MongoDB\Server\4.4\bin;C:\vcpkg;C:\cf-cli;C:\Program Files (x86)\NSIS;C:\tools\zstd;C:\Program Files\Mercurial;C:\h\windows\stack\2.7.1\x64;C:\tools\ghc-9.0.1\bin;C:\Program Files\dotnet;C:\mysql-5.7.21-winx64\bin;C:\Program Files\R\R-4.0.5\bin\x64;C:\SeleniumWebDrivers\GeckoDriver;C:\Program Files (x86)\GitHub CLI;C:\Program Files\Git\bin;C:\Program Files (x86)\pipx_bin;C:\h\windows\go\1.15.12\x64\bin;C:\h\windows\Python\3.7.9\x64\Scripts;C:\h\windows\Python\3.7.9\x64;C:\h\windows\Ruby\2.5.9\x64\bin;C:\h\windows\Java_Adopt_jdk\8.0.292-10\x64\bin;C:\aliyun-cli;C:\npm\prefix;C:\Program Files\Microsoft SDKs\Azure\Azure Dev Spaces CLI;C:\Program Files\Microsoft SDKs\Azure\Azure Dev Spaces CLI;C:\Program Files (x86)\Microsoft SDKs\Azure\CLI2\wbin;C:\Program Files\Microsoft MPI\Bin;C:\ProgramData\kind;C:\Windows\system32;C:\Windows;C:\Windows\System32\Wbem;C:\Windows\System32\WindowsPowerShell\v1.0;C:\Program Files\Microsoft\Web Platform Installer;C:\Program Files\Docker;C:\Program Files\PowerShell\7;C:\Program Files\dotnet;C:\Program Files\Microsoft SQL Server\130\Tools\Binn;C:\Program Files (x86)\Microsoft SQL Server\110\DTS\Binn;C:\Program Files (x86)\Microsoft SQL Server\120\DTS\Binn;C:\Program Files (x86)\Microsoft SQL Server\130\DTS\Binn;C:\Program Files (x86)\Microsoft SQL Server\140\DTS\Binn;C:\Program Files (x86)\Microsoft SQL Server\150\DTS\Binn;C:\Program Files (x86)\Windows Kits\10\Windows Performance Toolkit;C:\Program Files\Microsoft Service Fabric\bin\Fabric\Fabric.Code;C:\Program Files\Microsoft SDKs\Service Fabric\Tools\ServiceFabricLocalClusterManager;C:\Program Files\nodejs;C:\ProgramData\chocolatey\lib\pulumi\tools\Pulumi\bin;C:\ProgramData\chocolatey\lib\maven\apache-maven-3.8.1\bin;C:\Program Files\TortoiseSVN\bin;C:\SeleniumWebDrivers\ChromeDriver;C:\SeleniumWebDrivers\EdgeDriver;C:\Program Files\Amazon\AWSCLIV2;C:\Program Files\Amazon\SessionManagerPlugin\bin;C:\Program Files\Amazon\AWSSAMCLI\bin;C:\Program Files (x86)\Google\Cloud SDK\google-cloud-sdk\bin;C:\Users\VssAdministrator\AppData\Local\Microsoft\WindowsApps"
set "SCRIPTS=D:\bld\metamorpheus_1621080809326\_h_env\Scripts"
set "LIBRARY_PREFIX=D:\bld\metamorpheus_1621080809326\_h_env\Library"
set "LIBRARY_BIN=D:\bld\metamorpheus_1621080809326\_h_env\Library\bin"
set "LIBRARY_INC=D:\bld\metamorpheus_1621080809326\_h_env\Library\include"
set "LIBRARY_LIB=D:\bld\metamorpheus_1621080809326\_h_env\Library\lib"
set "CYGWIN_PREFIX=/cygdrive/d/bld/metamorpheus_1621080809326/_h_env"
set "ALLUSERSPROFILE=C:\ProgramData"
set "APPDATA=C:\Users\VssAdministrator\AppData\Roaming"
set "CommonProgramFiles=C:\Program Files\Common Files"
set "CommonProgramFiles(x86)=C:\Program Files (x86)\Common Files"
set "CommonProgramW6432=C:\Program Files\Common Files"
set "COMPUTERNAME=WIN-FPSJIVMJUML"
set "ComSpec=C:\Windows\system32\cmd.exe"
set "HOMEDRIVE=C:"
set "HOMEPATH=\Users\VssAdministrator"
set "LOCALAPPDATA=C:\Users\VssAdministrator\AppData\Local"
set "LOGONSERVER=\\WIN-FPSJIVMJUML"
set "NUMBER_OF_PROCESSORS=4"
set "PATHEXT=.COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC;.CPL"
set "ProgramData=C:\ProgramData"
set "ProgramFiles=C:\Program Files"
set "ProgramFiles(x86)=C:\Program Files (x86)"
set "ProgramW6432=C:\Program Files"
set "PROMPT=(base) $P$G"
set "PSModulePath=C:\Users\VssAdministrator\Documents\WindowsPowerShell\Modules;C:\Modules\azurerm_2.1.0;C:\Modules\azure_2.1.0;C:\Users\packer\Documents\WindowsPowerShell\Modules;C:\Program Files\WindowsPowerShell\Modules;C:\Windows\system32\WindowsPowerShell\v1.0\Modules;C:\Program Files\Microsoft SQL Server\130\Tools\PowerShell\Modules\;C:\Program Files (x86)\Google\Cloud SDK\google-cloud-sdk\platform\PowerShell"
set "PUBLIC=C:\Users\Public"
set "SystemDrive=C:"
set "SystemRoot=C:\Windows"
set "TEMP=C:\Users\VSSADM~1\AppData\Local\Temp"
set "TMP=C:\Users\VSSADM~1\AppData\Local\Temp"
set "USERDOMAIN=WIN-FPSJIVMJUML"
set "USERNAME=VssAdministrator"
set "USERPROFILE=C:\Users\VssAdministrator"
set "windir=C:\Windows"
set "PROCESSOR_ARCHITECTURE=AMD64"
set "PROCESSOR_IDENTIFIER=Intel64 Family 6 Model 85 Stepping 7, GenuineIntel"
set "BUILD=amd64-pc-windows-19.0.0"
set "VS140COMNTOOLS=C:\Program Files (x86)\Microsoft Visual Studio 14.0\Common7\Tools\"
set "extend_keys={'extend_keys', 'ignore_version', 'ignore_build_only_deps', 'pin_run_as_build'}"
set "ignore_build_only_deps={'python', 'numpy'}"
set "pin_run_as_build=OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')]))])"
set "channel_sources=conda-forge,defaults"
set "cxx_compiler=vs2017"
set "c_compiler=vs2017"
set "CI=azure"
set "cran_mirror=https://cran.r-project.org"
set "fortran_compiler=gfortran"
set "cpu_optimization_target=nocona"
set "channel_targets=conda-forge main"
set "target_platform=win-64"
set "r_base=3.4"
set "vc=14"
set "CONDA_BUILD_STATE=BUILD"
set "PIP_NO_BUILD_ISOLATION=False"
set "PIP_NO_DEPENDENCIES=True"
set "PIP_IGNORE_INSTALLED=True"
set "PIP_CACHE_DIR=D:\bld\metamorpheus_1621080809326\pip_cache"
set "PIP_NO_INDEX=True"
@echo on
set "INCLUDE=D:\bld\metamorpheus_1621080809326\_h_env\Library\include;%INCLUDE%"
set "LIB=D:\bld\metamorpheus_1621080809326\_h_env\Library\lib;%LIB%"
call "C:\Miniconda\Scripts\..\condabin\conda_hook.bat"
call "C:\Miniconda\Scripts\..\condabin\conda.bat" activate --stack "D:\bld\metamorpheus_1621080809326\_build_env"
